pub enum ScreenReaderEvent {
Noop,
StopSpeech,
Enable(Feature),
Disable(Feature),
ChangeMode(ScreenReaderMode),
StructuralNavigation(Direction, Role),
}Expand description
Events which can be trigged through Odilia’s external API. Subject to change without notice until v1.0, but we’re open to suggestions on our Github; please reach out with features you’d like to see.
Variants
Noop
when we need to do “something” but this is always hardcoded as nothing
StopSpeech
Stop all current speech.
Enable(Feature)
Enable a feature from working.
Disable(Feature)
Disable a feature.
ChangeMode(ScreenReaderMode)
Change mode of the screen reader. This is currently global, but it should be per application, and an update should only affect the current application.