ApplicationConfig

Struct ApplicationConfig 

pub struct ApplicationConfig { /* private fields */ }
type representing a read-only view of the odilia screenreader configuration this type should only be obtained as a result of parsing odilia’s configuration files, as it containes types for each section responsible for controlling various parts of the screenreader the only way this config should change is if the configuration file changes, in which case the entire view will be replaced to reflect the fact

Implementations

Source

impl ApplicationConfig

pub fn new(path: &str) -> Result<Self, ConfigError>

Opens a new config file with a certain path.

Errors

This can return Err(_) if the path doesn’t exist, or if not all the key/value pairs are defined.

pub fn log(&self) -> &LogSettings

pub fn speech(&self) -> &SpeechSettings